##
##  apache-tomcat.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2024 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         apache-tomcat
Summary:      Apache Extension: Tomcat/JSP Adapter
URL:          http://jakarta.apache.org/
Vendor:       Apache Software Foundation
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Web
License:      Apache Software License 2.0
Version:      1.2.50
Release:      20240824

#   list of sources
Source0:      http://www.apache.org/dist/tomcat/tomcat-connectors/jk/tomcat-connectors-%{version}-src.tar.gz
Source1:      apache-tomcat.conf
Source2:      apache-tomcat.workers

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, make
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  apache, apr
PreReq:       apache, apr

%description
    Apache Jakarta Tomcat webserver adapter is a glue code between the
    Apache HTTP server and Apache Tomcat. This package contains the
    mod_jk connector module for Apache.

%track
    prog apache-tomcat = {
        version   = %{version}
        url       = http://www.apache.org/dist/tomcat/tomcat-connectors/jk/
        regex     = tomcat-connectors-(__VER__)-src\.tar\.gz
    }

%prep
    %setup -q -n tomcat-connectors-%{version}-src/native

%build
    #   configure DSO
    CC="`%{l_prefix}/sbin/apxs -q CC`" \
    CFLAGS="`%{l_prefix}/sbin/apxs -q CFLAGS`" \
    ./configure \
        --prefix=%{l_prefix} \
        --with-apr=%{l_prefix} \
        --with-apxs=%{l_prefix}/sbin/apxs

    #   build DSO
    %{l_make} %{l_mflags}

%install

    #   create installation tree
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/etc/apache-tomcat \
        $RPM_BUILD_ROOT%{l_prefix}/etc/apache/apache.d \
        $RPM_BUILD_ROOT%{l_prefix}/libexec/apache \
        $RPM_BUILD_ROOT%{l_prefix}/var/apache-tomcat

    #   install config
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        %{SOURCE apache-tomcat.workers} \
        $RPM_BUILD_ROOT%{l_prefix}/etc/apache-tomcat/workers.properties
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        %{SOURCE apache-tomcat.conf} \
        $RPM_BUILD_ROOT%{l_prefix}/etc/apache/apache.d/

    #   install mod_jk DSO
    %{l_shtool} install -c -m 755 \
        apache-2.0/mod_jk.so \
        $RPM_BUILD_ROOT%{l_prefix}/libexec/apache/mod_jk.so

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%config %{l_prefix}/etc/apache-tomcat/workers.properties' \
        '%config %{l_prefix}/etc/apache/apache.d/apache-tomcat.conf'

%files -f files

%clean

%post
    #   after upgrade, restart service
    [ $1 -eq 2 ] || exit 0
    eval `%{l_rc} apache status 2>/dev/null`
    [ ".$apache_active" = .yes ] && %{l_rc} apache restart
    exit 0

